#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall
version:              1.42.3
visibility:           public
id:                   dhall-1.42.3-Ax6qqfYDUytDCRJsLw6D9T
key:                  dhall-1.42.3-Ax6qqfYDUytDCRJsLw6D9T
license:              BSD-3-Clause
copyright:            2017 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             A configuration language guaranteed to terminate
description:
    Dhall is an explicitly typed configuration language that is not Turing
    complete.  Despite being Turing incomplete, Dhall is a real programming
    language with a type-checker and evaluator.

    Use this library to parse, type-check, evaluate, and pretty-print the Dhall
    configuration language.  This package also includes an executable which
    type-checks a Dhall file and reduces the file to a fully evaluated normal
    form.

    Read "Dhall.Tutorial" to learn how to use this library

category:             Compiler
abi:                  fb98caa0992db4e888a51b4225f93230
exposed:              True
exposed-modules:
    Dhall Dhall.Binary Dhall.Context Dhall.Core Dhall.Crypto
    Dhall.Deriving Dhall.Diff Dhall.DirectoryTree Dhall.Format
    Dhall.Freeze Dhall.Import Dhall.Lint Dhall.Main Dhall.Map
    Dhall.Marshal.Decode Dhall.Marshal.Encode Dhall.Optics
    Dhall.Package Dhall.Parser Dhall.Parser.Expression
    Dhall.Parser.Token Dhall.Pretty Dhall.Repl Dhall.Schemas Dhall.Set
    Dhall.Src Dhall.Substitution Dhall.TH Dhall.Tags Dhall.Tutorial
    Dhall.TypeCheck Dhall.Util Dhall.Version

hidden-modules:
    Dhall.DirectoryTree.Types Dhall.Eval Dhall.Import.Types
    Dhall.Import.Headers Dhall.Marshal.Internal Dhall.Normalize
    Dhall.Parser.Combinators Dhall.Pretty.Internal Dhall.Syntax
    Dhall.Syntax.Binding Dhall.Syntax.Chunks Dhall.Syntax.Const
    Dhall.Syntax.Expr Dhall.Syntax.FunctionBinding Dhall.Syntax.Import
    Dhall.Syntax.Instances.Applicative Dhall.Syntax.Instances.Bifunctor
    Dhall.Syntax.Instances.Data Dhall.Syntax.Instances.Eq
    Dhall.Syntax.Instances.Foldable Dhall.Syntax.Instances.Functor
    Dhall.Syntax.Instances.Lift Dhall.Syntax.Instances.Monad
    Dhall.Syntax.Instances.NFData Dhall.Syntax.Instances.Ord
    Dhall.Syntax.Instances.Pretty Dhall.Syntax.Instances.Show
    Dhall.Syntax.Instances.Traversable Dhall.Syntax.MultiLet
    Dhall.Syntax.Operations Dhall.Syntax.RecordField Dhall.Syntax.Types
    Dhall.Syntax.Var Dhall.URL Paths_dhall Dhall.Import.HTTP
    Dhall.Import.Manager

import-dirs:          /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall
hs-libraries:         HSdhall-1.42.3-Ax6qqfYDUytDCRJsLw6D9T
depends:
    Diff-0.5-1NGQ2AwAw3pDIUtg9aS2pi
    aeson-2.2.1.0-BfV39Vpjeh9G4TP9CsFVxm
    aeson-pretty-0.8.10-FAAZTIWR3qFEp21Mcrhufh
    ansi-terminal-1.1-9ylD0rKiZSECqFezPHrURT
    atomic-write-0.2.1.1-4eQqITJ0MYyHO44kNmsvf3 base-4.18.2.1
    base16-bytestring-1.0.2.0-BqWVRU1IQoAP0y3rqebgF bytestring-0.11.5.3
    case-insensitive-1.2.1.0-77TInwzUoLr4ZTB9XsbUbo
    cborg-0.2.10.0-16xFmRS1I9aEBLReY035rN
    cborg-json-0.2.6.0-BlJfZ0lQ9sn57jNoiStDHt containers-0.6.7
    contravariant-1.5.5-JUOgBPNZkO18h7ix7HMuaW
    cryptohash-sha256-0.11.102.1-FEOISJh9tz9IkHgKR1nOJi
    data-fix-0.3.4-CS2hA3yEC8z41o6f15mEpZ deepseq-1.4.8.1
    directory-1.3.8.5 dotgen-0.4.3-A2UTkkV6Fes7fbL6Rpf3sY
    either-5.0.3-KfBJXdfyjxnAY8ILwifqPV exceptions-0.10.7
    filepath-1.4.300.1 half-0.3.3-Ep1tmf9BzMbFsQjAfJP4ai
    hashable-1.4.7.0-D2jhP8LVtgFIAnKx76ZNYr haskeline-0.8.2.1
    http-client-0.7.19-HpBpFDcF8eMLX9tct0xZ3w
    http-client-tls-0.3.6.4-1EC6Bajh6K7FgvqmScIMPu
    http-types-0.12.4-E7NglevSDUe4aFzTHGY2t7
    indexed-traversable-0.1.4-8j5HZpShpE5BqFup9Ojenr
    megaparsec-9.7.0-DXs8laDhUphAhuuvlpoJQn
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    microlens-mtl-0.2.1.0-Ewo8HmKpWhTASatFX3KZGS
    mmorph-1.2.1-FckgyjrzQqj9FpiKudKdHK mtl-2.3.1
    network-uri-2.6.4.2-Gnw0MjQFVGhFnasOtB45
    optparse-applicative-0.18.1.0-7EdJH1WM84m2Q8FpgsqIZk
    parser-combinators-1.3.1-8aQ8dKOwDVmFxT1S1WvW6m
    parsers-0.12.12-AGaSC4Wq7b2EeJ8kVizOWA
    pretty-simple-4.1.4.0-DTJzEClc91zACORaeS2Kci
    prettyprinter-1.7.1-6jg14vIwDos4Lqu7eMpEik
    prettyprinter-ansi-terminal-1.1.3-25dNCVEFp3dGuk7ZV0yUf5
    repline-0.4.3.0-8K1qOV9c7aG2gqDtsaBJvy
    scientific-0.3.8.1-DLJUsVzfkt8S4sgDRE9je
    serialise-0.2.6.1-LgCz5Xi2Wxtkt6YD6cpqE template-haskell-2.20.0.0
    text-2.0.2 text-manipulate-0.3.1.0-5BpdaGOVYhJAFplDYd2hfK
    text-short-0.1.6-BH7OsSc5poU6BDsxWGqEHD
    th-lift-instances-0.1.20-HDAnLUi7uuP4e7mmWpK90f time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unix-compat-0.7.4.1-HvE9rDfewkQ13p4jO6TiTm
    unordered-containers-0.2.20.1-ZzaTCzIdz8BWoPLHKXAc8
    vector-0.13.2.0-5VH4z5LB2hn3qUPNgI7cRE

haddock-interfaces:   /usr/share/doc/dhall/html/dhall.haddock
haddock-html:         /usr/share/doc/dhall/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

